=========================
gemviz: View Bluesky Data
=========================

.. list-table::
   :widths: 1 2

   * - ..  figure:: _static/gemviz_gui.png
           :alt: fig.gemviz_gui
     - * Browse catalogs of Bluesky data
       * Search for data by keywords or date
       * Visualize (1-D plots now)

.. icons: https://fonts.google.com/icons
.. grid:: 3

    .. grid-item-card:: :material-regular:`summarize;3em` User Guide
      :link: user_guide
      :link-type: doc

    .. grid-item-card:: :material-regular:`install_desktop;3em` Install
      :link: install
      :link-type: doc

    .. grid-item-card:: :material-regular:`api;3em` API
      :link: api
      :link-type: doc

.. toctree::
   :maxdepth: 2
   :glob:
   :caption: Contents:
   :hidden:

   user_guide
   install
   api
   license
   changes

:home: https://bcda-aps.github.io/gemviz/
:bug tracker: https://github.com/BCDA-APS/gemviz/issues
:source: https://github.com/BCDA-APS/gemviz
:license: :ref:`license`
:full version: |release|
:published: |today|
:revisions: :ref:`History of code changes <changes>`
:index: :ref:`genindex`
:module: :ref:`modindex`
:search: :ref:`search`

Acknowledgements
====================

We'd like to thank the GEM fellow program (https://www.gemfellowship.org/) for
sponsoring an intern fellowship for the development of this software at the
Advanced Photon Source.

"This product includes software produced by UChicago Argonne, LLC
under Contract No. DE-AC02-06CH11357 with the Department of Energy."
